Skip to contents

Transparent paper/plot backgrounds and ink that follows the resolved preset. Requires plotly. Call as plotly_glass(p) or do.call(plotly::layout, c(list(p), plotly_glass())).

Usage

plotly_glass(
  p = NULL,
  preset = NULL,
  input = NULL,
  surface = c("clear", "opaque")
)

Arguments

p

Optional plotly object. When NULL, returns a named list of layout arguments.

preset, input, surface

See glass_plot_colors().

Value

p with layout applied, or a list of layout arguments.